port = 8125
percentThresholds = (90, 75)
flushInterval = 10.0 # Seconds to flush stats
timerPrefix = 'stats.timers'
counterPrefix = 'stats'
gaugePrefix = 'stats'
deleteCounters = False

graphitePort = 2003
graphiteHost = 'localhost'
graphiteConnRetry = 5 # Seconds to wait before re-establishing connection
